@@ -16,9 +16,11 @@ joint4 = ssc['joint4']
 grip = ssc['grip']
 
 #for i in xrange(16):
-#    ssc[i].degree = 0
+#    ssc[i].degrees = 0
 
 
+joint0.degrees = 60
+
 go_default = [(joint0, 0, 0),
               (joint1, -130, 0),
               (joint2, -45, 0),
@@ -33,13 +35,13 @@ def script(scr):
     (servo, deg, wait_time)
     """
     for move in scr:
-        move[0].degree = move[1]
+        move[0].degrees = move[1]
         while not ssc.is_done():
             time.sleep(0.01)
         time.sleep(move[2])
 
 # initial
-ssc.autocommit = 400
+ssc.autocommit = 500
 script(go_default)
 ssc.autocommit = 1000
 
